summaryrefslogtreecommitdiffstats
path: root/kpilot/lib/recordConduit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpilot/lib/recordConduit.h')
-rw-r--r--kpilot/lib/recordConduit.h18
1 files changed, 9 insertions, 9 deletions
diff --git a/kpilot/lib/recordConduit.h b/kpilot/lib/recordConduit.h
index d12ceef2..743e326d 100644
--- a/kpilot/lib/recordConduit.h
+++ b/kpilot/lib/recordConduit.h
@@ -27,7 +27,7 @@
** Bug reports and questions can be sent to kde-pim@kde.org
*/
-#include <qtimer.h>
+#include <tqtimer.h>
#include <klocale.h>
#include "plugin.h"
@@ -57,11 +57,11 @@ class RecordConduitBase : public ConduitAction
{
Q_OBJECT
public:
/** Constructor. The QStringList @p a sets flags for the ConduitAction.
*/
RecordConduitBase(KPilotDeviceLink *o,
const char *n,
- const QStringList a = QStringList()) :
+ const TQStringList a = TQStringList()) :
ConduitAction(o,n,a),
fTimer(0L)
{
@@ -80,12 +80,12 @@ public:
enum SyncProgress { NotDone=0, Done=1, Error=2 } ;
/** Returns a human-readable name for the progress indicator @p s */
- static QString name(SyncProgress s);
+ static TQString name(SyncProgress s);
/** State of the conduit's sync. This is changed by process(). */
enum States { Initialize, PalmToPC, PCToPalm, Cleanup } ;
- static QString name(States s);
+ static TQString name(States s);
protected:
/** Function called at the beginning of a sync to load data from the PC.
@@ -129,14 +129,14 @@ protected:
private:
/** Timer to signal the process() slot. Used to keep the UI responsive. */
- QTimer *fTimer;
+ TQTimer *fTimer;
States fState;
Pilot::RecordIDList fIDList;
Pilot::RecordIDList::Iterator fIDListIterator;
- QString fDBName;
+ TQString fDBName;
} ;
template <class PCEntry, class PCContainer, class HHEntry, class HHAppInfo, class Syncer>
@@ -146,8 +146,8 @@ public:
/** Construct a record conduit on a given device link. */
RecordConduit(
KPilotDeviceLink *o /**< Connection to HH */,
- const char *n /**< Name for QObject */,
- const QStringList a = QStringList() /**< Flags */) :
+ const char *n /**< Name for TQObject */,
+ const TQStringList a = TQStringList() /**< Flags */) :
RecordConduitBase(o,n,a)
{
} ;
@@ -57,11 +57,11 @@ class RecordConduitBase : public ConduitAction
Q_OBJECT
public:
- /** Constructor. The QStringList @p a sets flags for the ConduitAction.
+ /** Constructor. The TQStringList @p a sets flags for the ConduitAction.
*/
RecordConduitBase(KPilotDeviceLink *o,